EdcClusterClusterConfigIonosS3InlineConnectionInlineTlsVerificationServerCaCert

Struct EdcClusterClusterConfigIonosS3InlineConnectionInlineTlsVerificationServerCaCert 

pub struct EdcClusterClusterConfigIonosS3InlineConnectionInlineTlsVerificationServerCaCert {
    pub secret_class: Option<String>,
    pub web_pki: Option<EdcClusterClusterConfigIonosS3InlineConnectionInlineTlsVerificationServerCaCertWebPki>,
}
CA cert to verify the server.

Fields

secret_class: Option<String>

Name of the [SecretClass](https://docs.stackable.tech/home/nightly/secret-operator/secretclass) which will provide the CA certificate. Note that a SecretClass does not need to have a key but can also work with just a CA certificate, so if you got provided with a CA cert but don’t have access to the key you can still use this method.

web_pki: Option<EdcClusterClusterConfigIonosS3InlineConnectionInlineTlsVerificationServerCaCertWebPki>

Use TLS and the CA certificates trusted by the common web browsers to verify the server. This can be useful when you e.g. use public AWS S3 or other public available services.